import Unocss from "unocss/vite";
import transformerVariantGroup from "@unocss/transformer-variant-group";
import presetUno from '@unocss/preset-uno';
import presetWind from '@unocss/preset-wind';
import presetIcons from '@unocss/preset-icons';
import { presetScrollbar } from 'unocss-preset-scrollbar';

import chroma from "chroma-js";

export const colors = {
    primary: "#409eff",
    success: "#67c23a",
    warning: "#e6a23c",
    danger: "#f56c6c",
    info: "#909399",
};

export default {


    transformers: [transformerVariantGroup()],

    presets: [
      presetUno(),
      presetWind(),
      presetIcons({
          collections: {
              ep: () => import('@iconify-json/ep/icons.json').then(i => i.default),
          },
      }),
      presetScrollbar({

      }),
      
    ],

    theme: {
      colors: {

        base: {
          DEFAULT: "#ffffff",
          100: "#ffffff",
          200: "#f0f2f5",
          300: "#e6e9f0",
        },   

        primary: {
          DEFAULT: colors.primary,
          50: chroma.mix("white", colors.primary, 0.1).hex(),
          100: chroma.mix("white", colors.primary, 0.2).hex(),
          200: chroma.mix("white", colors.primary, 0.4).hex(),
          300: chroma.mix("white", colors.primary, 0.6).hex(),
          400: chroma.mix("white", colors.primary, 0.8).hex(),
          500: colors.primary,
          600: chroma.mix("black", colors.primary, 0.8).hex(),
          700: chroma.mix("black", colors.primary, 0.6).hex(),
          800: chroma.mix("black", colors.primary, 0.4).hex(),
          900: chroma.mix("black", colors.primary, 0.2).hex(),
          content: "#ffffff",
        },

        success: {
          DEFAULT: colors.success,
          50: chroma.mix("white", colors.success, 0.1).hex(),
          100: chroma.mix("white", colors.success, 0.2).hex(),
          200: chroma.mix("white", colors.success, 0.4).hex(),
          300: chroma.mix("white", colors.success, 0.6).hex(),
          400: chroma.mix("white", colors.success, 0.8).hex(),
          500: colors.success,
          600: chroma.mix("black", colors.success, 0.8).hex(),
          700: chroma.mix("black", colors.success, 0.6).hex(),
          800: chroma.mix("black", colors.success, 0.4).hex(),
          900: chroma.mix("black", colors.success, 0.2).hex(),
          content: "#ffffff",
        },

        warning: {
          DEFAULT: colors.warning,
          50: chroma.mix("white", colors.warning, 0.1).hex(),
          100: chroma.mix("white", colors.warning, 0.2).hex(),
          200: chroma.mix("white", colors.warning, 0.4).hex(),
          300: chroma.mix("white", colors.warning, 0.6).hex(),
          400: chroma.mix("white", colors.warning, 0.8).hex(),
          500: colors.warning,
          600: chroma.mix("black", colors.warning, 0.8).hex(),
          700: chroma.mix("black", colors.warning, 0.6).hex(),
          800: chroma.mix("black", colors.warning, 0.4).hex(),
          900: chroma.mix("black", colors.warning, 0.2).hex(),
          content: "#ffffff",
        },

        danger: {
          DEFAULT: colors.danger,
          50: chroma.mix("white", colors.danger, 0.1).hex(),
          100: chroma.mix("white", colors.danger, 0.2).hex(),
          200: chroma.mix("white", colors.danger, 0.4).hex(),
          300: chroma.mix("white", colors.danger, 0.6).hex(),
          400: chroma.mix("white", colors.danger, 0.8).hex(),
          500: colors.danger,
          600: chroma.mix("black", colors.danger, 0.8).hex(),
          700: chroma.mix("black", colors.danger, 0.6).hex(),
          800: chroma.mix("black", colors.danger, 0.4).hex(),
          900: chroma.mix("black", colors.danger, 0.2).hex(),
          content: "#ffffff",
        },

        info: {
          DEFAULT: colors.info,
          50: chroma.mix("white", colors.info, 0.1).hex(),
          100: chroma.mix("white", colors.info, 0.2).hex(),
          200: chroma.mix("white", colors.info, 0.4).hex(),
          300: chroma.mix("white", colors.info, 0.6).hex(),
          400: chroma.mix("white", colors.info, 0.8).hex(),
          500: colors.info,
          600: chroma.mix("black", colors.info, 0.8).hex(),
          700: chroma.mix("black", colors.info, 0.6).hex(),
          800: chroma.mix("black", colors.info, 0.4).hex(),
          900: chroma.mix("black", colors.info, 0.2).hex(),
          content: "#ffffff",
        },

        text: {
          primary: "#303133",
          regular: "#606266",
          secondary: "#909399",
          placeholder: "#a8abb2",
          disabled: "#c0c4cc",
        },
      },      
    },

    shortcuts: [
      
      /* Generics */
      {
        'is-circle': 'p-2 rounded-full',

        'is-disabled': 'cursor-not-allowed opacity-60',

        'is-loading': 'is-disabled !cursor-wait',
        
        'is-block': 'w-full',
      },

      /* Button shortcuts */
      {
        btn: "py-1.25 px-4 inline-flex bg-base-100 text-gray-500 border-gray-300 border rounded enabled:hover:(bg-primary-100 text-primary-500) enabled:active:(border-primary-500)",
        "btn-primary":
          "btn bg-primary-500 border-primary-500 text-primary-content !enabled:hover:(bg-primary-400 border-primary-400 text-primary-content) !enabled:active:(bg-primary-600 border-primary-600 text-primary-content)",
        "btn-success":
          "btn bg-success-500 border-success-500 text-success-content !enabled:hover:(bg-success-400 border-success-400 text-success-content) !enabled:active:(bg-success-600 border-success-600 text-success-content)",
        "btn-warning":
          "btn bg-warning-500 border-warning-500 text-warning-content !enabled:hover:(bg-warning-400 border-warning-400 text-warning-content) !enabled:active:(bg-warning-600 border-warning-600 text-warning-content)",
        "btn-danger":
          "btn bg-danger-500 border-danger-500 text-danger-content !enabled:hover:(bg-danger-400 border-danger-400 text-danger-content) !enabled:active:(bg-danger-600 border-danger-600 text-danger-content)",
        "btn-info":
          "btn bg-info-500 border-info-500 text-info-content !enabled:hover:(bg-info-400 border-info-400 text-info-content) !enabled:active:(bg-info-600 border-info-600 text-info-content)",
        "btn--plain": "btn !enabled:hover:(text-primary-500 border-primary-500 bg-base-100)",
        
        'btn--small': 'text-size-12px',
        'btn--medium': 'text-size-16px py-1.5 px-5',
        'btn--large': 'text-size-18px py-2 px-6',
        
      },

      [/^btn-(.*)--plain$/, ([, c]) => `btn border-${c}-300 bg-${c}-50 text-${c}-500 !enabled:hover:(bg-${c}-500 border-${c}-500 text-${c}-content) !enabled:active:(bg-${c}-600 border-${c}-600 text-${c}-content)`],

      /* Icon shortcuts */
      [/^icon-(.*)$/, ([, c]) => `i-ep-${c}`],

      {
        'icon__left': 'self-center -ml-1.5 mr-1.5',
        'icon__right': 'self-center ml-1.5 -mr-1.5',
      },

      /* Input shortcuts */
      {
        'input': 'bg-base-100 border-gray-300 border rounded px-2 py-1 text-gray-500 placeholder-gray-300 enabled:hover:(border-gray-400) enabled:focus:(outline-none border-primary-500)',
        'input--small': 'text-size-12px py-0.5 px-2',
        'input--medium': 'text-size-16px py-1.5 px-3',
        'input--large': 'text-size-18px py-2 px-5',

        'input-primary': 'input border-primary-300 !enabled:hover:(border-primary-400) !enabled:focus:(outline outline-primary-200 border-primary-300)',
        'input-danger': 'input border-danger-300 !enabled:hover:(border-danger-400) !enabled:focus:(outline outline-danger-200 border-danger-300)',
        'input-success': 'input border-success-300 !enabled:hover:(border-success-400) !enabled:focus:(outline outline-success-200 border-success-300)',
        'input-warning': 'input border-warning-300 !enabled:hover:(border-warning-400) !enabled:focus:(outline outline-warning-200 border-warning-300)',
        'input-info': 'input border-info-300 !enabled:hover:(border-info-400) !enabled:focus:(outline outline-info-200 border-info-300)',
        
      },
      

    ],



  }